@@ -2,7 +2,7 @@
 """clipboard module"""
 import os
 import subprocess
-from subprocess import CalledProcessError
+from subprocess import CalledProcessError, DEVNULL
 
 class Clipboard:
     """Class implements copying note content to the clipboard"""
@@ -14,17 +14,26 @@ class Clipboard:
         """Defines the copy command based on the contents of $PATH"""
 
         try:
-            subprocess.check_output(['which', 'xsel'])
+            subprocess.check_call(['which', 'xsel'], stdout=DEVNULL, \
+                    stderr=DEVNULL)
             return 'echo "%s" | xsel -ib'
         except CalledProcessError:
             pass
 
         try:
-            subprocess.check_output(['which', 'pbcopy'])
+            subprocess.check_call(['which', 'pbcopy'], stdout=DEVNULL, \
+                    stderr=DEVNULL)
             return 'echo "%s" | pbcopy'
         except CalledProcessError:
             pass
 
+        try:
+            subprocess.check_call(['which', 'xclip'], stdout=DEVNULL, \
+                    stderr=DEVNULL)
+            return 'echo "%s" | xclip -selection clipboard'
+        except CalledProcessError:
+            pass
+
         return None
 
     def copy(self, text):
