@@ -50,7 +50,7 @@ class NncliGui:
                     }
                     )
 
-        self.view_log = view_log.ViewLog(self.config)
+        self.view_log = view_log.ViewLog(self.config, self.logger)
         self.view_help = view_help.ViewHelp(self.config)
 
         palette = \
@@ -854,9 +854,8 @@ class NncliGui:
             # clear the screen and exit the urwid run loop
             self._gui_clear()
             raise urwid.ExitMainLoop()
-        else:
-            self.log('WARNING: Not all notes saved'
-                     'to disk (wait for sync worker)')
+        self.log('WARNING: Not all notes saved'
+                 'to disk (wait for sync worker)')
 
     def log(self, msg):
         """Log as message, displaying to the user as appropriate"""
@@ -897,8 +896,7 @@ class NncliGui:
             self._gui_footer_log_clear()
             self.logs = []
         else:
-            # for some reason having problems with this being empty?
-            if not self.logs:
+            if self.logs:
                 self.logs.pop(0)
 
             log_pile = []
